@@ -42,9 +42,10 @@ class HttpClient(object):
     ip_address = None
     endpoint = None
 
-    def __init__(self, tls_version=utils.DEFAULT_TLS_VERSION):
+    def __init__(self, tls_version=utils.DEFAULT_TLS_VERSION, cert=None):
         self._tls_session = Session()
         self._tls_session.mount("http://", UseTlsAdapter(tls_version))
+        self.cert = cert
 
     def __enter__(self):
         return self
@@ -54,7 +55,7 @@ class HttpClient(object):
 
     def _do_request(self, http_method, rest_command,
                     parameters=None,
-                    file=None, headers=None, cert=None):
+                    file=None, headers=None):
         """Perform a HTTP request.
 
         :param http_method: GET or POST.
@@ -77,14 +78,14 @@ class HttpClient(object):
                                                          verify=False,
                                                          data=payload,
                                                          headers=headers,
-                                                         cert=cert)
+                                                         cert=self.cert)
             else:
                 response = self._tls_session.request(http_method, cmd_url,
                                                      params=parameters,
                                                      timeout=utils.TIMEOUT,
                                                      verify=False,
                                                      headers=headers,
-                                                     cert=cert)
+                                                     cert=self.cert)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text)
             else:
@@ -121,10 +122,6 @@ class HttpClient(object):
         return self._do_request('POST', rest_command, parameters=parameters,
                                 file=file, headers=headers)
 
-    def _get_curl_command_list(self, command):
-        return ['curl', '-s', '-k', '--connect-timeout', str(utils.TIMEOUT),
-                '{}/{}'.format(self.endpoint, command)]
-
 
 def send_response(response):
 
@@ -137,15 +134,15 @@ def send_response(response):
 class LoadMaster(HttpClient):
     """LoadMaster API object."""
 
-    def __init__(self, ip, username, password, port=443, cert=None,
-                 tls_version=utils.DEFAULT_TLS_VERSION):
+    def __init__(self, ip, username=None, password=None, port=443,
+                 cert=None):
         self.ip_address = ip
         self.username = username
         self.password = password
         self.port = port
-        self.version = None
         self.cert = cert
-        super(LoadMaster, self).__init__(tls_version)
+        self.version = None
+        super(LoadMaster, self).__init__(utils.DEFAULT_TLS_VERSION, self.cert)
 
     def __repr__(self):
         return '{}:{}'.format(self.ip_address, self.port)
@@ -178,6 +175,14 @@ class LoadMaster(HttpClient):
             self.version = "7.1.34"
         return CAPABILITIES.get(self.version, CAPABILITIES[DEFAULT])
 
+    def _get_curl_command_list(self, command):
+        curl = ['curl', '-s', '-k', '--connect-timeout', str(utils.TIMEOUT)]
+        command = '{}/{}'.format(self.endpoint, command)
+        if self.cert:
+            curl.extend(['-E', self.cert])
+        curl.append(command)
+        return curl
+
     def create_virtual_service(self, ip, port=80, protocol="tcp"):
         """VirtualService factory with pre-configured LoadMaster connection."""
         vs = VirtualService(self.access_info, ip, port, protocol)
@@ -497,6 +502,8 @@ class LoadMaster(HttpClient):
 
     def set_user_perms(self, user, perms=None):
         perms = [] if perms is None else perms
+        if not isinstance(perms, list):
+            perms = [perms]
         params = {
             'user': user,
             'perms': ",".join([perm for perm in perms]),
